@@ -6,11 +6,12 @@
  *
  * Copyright (c) 1990-1994 The Regents of the University of California.
  * Copyright (c) 1994-1997 Sun Microsystems, Inc.
+ * Copyright (c) 1998 by Scriptics Corporation.
  *
  * See the file "license.terms" for information on usage and redistribution
  * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
  *
- * SCCS: @(#) tkInt.h 1.204 97/10/31 09:55:20
+ * RCS: $Id: tkInt.h,v 1.8 1998/09/30 19:01:20 rjohnson Exp $ 
  */
 
 #ifndef _TKINT
@@ -19,6 +20,10 @@
 #ifndef _TK
 #include "tk.h"
 #endif
+#ifdef BUILD_tk
+# undef TCL_STORAGE_CLASS
+# define TCL_STORAGE_CLASS DLLEXPORT
+#endif
 
 /*
  * Opaque type declarations:
@@ -701,8 +706,6 @@ EXTERN char *		TkAlignImageData _ANSI_ARGS_((XImage *image,
 			    int alignment, int bitOrder));
 EXTERN TkWindow *	TkAllocWindow _ANSI_ARGS_((TkDisplay *dispPtr,
 			    int screenNum, TkWindow *parentPtr));
-MOVEXT int		TkAreaToPolygon _ANSI_ARGS_((double *polyPtr,
-			    int numPoints, double *rectPtr));
 MOVEXT void		TkBezierPoints _ANSI_ARGS_((double control[],
 			    int numSteps, double *coordPtr));
 MOVEXT void		TkBezierScreenPoints _ANSI_ARGS_((Tk_Canvas canvas,
@@ -754,8 +757,6 @@ EXTERN void		TkDoConfigureNotify _ANSI_ARGS_((TkWindow *winPtr));
 EXTERN void		TkDrawInsetFocusHighlight _ANSI_ARGS_((
 			    Tk_Window tkwin, GC gc, int width,
 			    Drawable drawable, int padding));
-EXTERN void		TkEventCleanupProc _ANSI_ARGS_((
-			    ClientData clientData, Tcl_Interp *interp));
 EXTERN void		TkEventDeadWindow _ANSI_ARGS_((TkWindow *winPtr));
 EXTERN void		TkFillPolygon _ANSI_ARGS_((Tk_Canvas canvas,
 			    double *coordPtr, int numPoints, Display *display,
@@ -798,9 +799,6 @@ EXTERN int		TkGetInterpNames _ANSI_ARGS_((Tcl_Interp *interp,
 MOVEXT int		TkGetMiterPoints _ANSI_ARGS_((double p1[], double p2[],
 			    double p3[], double width, double m1[],
 			    double m2[]));
-#ifndef TkGetNativeProlog
-EXTERN int		TkGetNativeProlog _ANSI_ARGS_((Tcl_Interp *interp));
-#endif
 EXTERN void		TkGetPointerCoords _ANSI_ARGS_((Tk_Window tkwin,
 			    int *xPtr, int *yPtr));
 EXTERN int		TkGetProlog _ANSI_ARGS_((Tcl_Interp *interp));
@@ -808,8 +806,6 @@ EXTERN void		TkGetServerInfo _ANSI_ARGS_((Tcl_Interp *interp,
 			    Tk_Window tkwin));
 EXTERN void		TkGrabDeadWindow _ANSI_ARGS_((TkWindow *winPtr));
 EXTERN int		TkGrabState _ANSI_ARGS_((TkWindow *winPtr));
-EXTERN TkWindow *      	TkIDToWindow _ANSI_ARGS_((Window window, 
-			    TkDisplay *display));
 MOVEXT void		TkIncludePoint _ANSI_ARGS_((Tk_Item *itemPtr,
 			    double *pointPtr));
 EXTERN void		TkInitXId _ANSI_ARGS_((TkDisplay *dispPtr));
@@ -827,12 +823,6 @@ MOVEXT int		TkLineToArea _ANSI_ARGS_((double end1Ptr[2],
 			    double end2Ptr[2], double rectPtr[4]));
 MOVEXT double		TkLineToPoint _ANSI_ARGS_((double end1Ptr[2],
 			    double end2Ptr[2], double pointPtr[2]));
-EXTERN int		TkListAppend _ANSI_ARGS_((void **headPtrPtr,
-			    void *itemPtr, size_t size));
-EXTERN int		TkListDelete _ANSI_ARGS_((void **headPtrPtr,
-			    void *itemPtr, size_t size));
-EXTERN void *		TkListFind _ANSI_ARGS_((void *headPtr, void *itemPtr,
-			    size_t size));
 MOVEXT int		TkMakeBezierCurve _ANSI_ARGS_((Tk_Canvas canvas,
 			    double *pointPtr, int numPoints, int numSteps,
 			    XPoint xPoints[], double dblPoints[]));
@@ -926,6 +916,12 @@ EXTERN void		TkpWmSetState _ANSI_ARGS_((TkWindow *winPtr,
 			    int state));
 EXTERN void		TkQueueEventForAllChildren _ANSI_ARGS_((
 			    TkWindow *winPtr, XEvent *eventPtr));
+EXTERN int		TkReadBitmapFile _ANSI_ARGS_((Display* display,
+			    Drawable d, CONST char* filename,
+			    unsigned int* width_return,
+			    unsigned int* height_return,
+			    Pixmap* bitmap_return,
+			    int* x_hot_return, int* y_hot_return));
 #ifndef TkRectInRegion
 EXTERN int		TkRectInRegion _ANSI_ARGS_((TkRegion rgn,
 			    int x, int y, unsigned int width,
@@ -974,8 +970,6 @@ EXTERN void		TkWmRestackToplevel _ANSI_ARGS_((TkWindow *winPtr,
 			    int aboveBelow, TkWindow *otherPtr));
 EXTERN void		TkWmSetClass _ANSI_ARGS_((TkWindow *winPtr));
 EXTERN void		TkWmUnmapWindow _ANSI_ARGS_((TkWindow *winPtr));
-EXTERN int		TkXFileProc _ANSI_ARGS_((ClientData clientData,
-			    int mask, int flags));
 
 /* 
  * Unsupported commands.
@@ -983,4 +977,7 @@ EXTERN int		TkXFileProc _ANSI_ARGS_((ClientData clientData,
 EXTERN int		TkUnsupported1Cmd _ANSI_ARGS_((ClientData clientData,
 			    Tcl_Interp *interp, int argc, char **argv));
 
+# undef TCL_STORAGE_CLASS
+# define TCL_STORAGE_CLASS DLLIMPORT
+
 #endif  /* _TKINT */
