@@ -11,7 +11,7 @@
  * See the file "license.terms" for information on usage and redistribution
  * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
  *
- * SCCS: @(#) tkSelect.c 1.57 96/05/03 10:52:40
+ * RCS: @(#) $Id: tkSelect.c,v 1.2 1998/09/14 18:23:17 stanton Exp $
  */
 
 #include "tkInt.h"
@@ -550,7 +550,7 @@ Tk_GetXSelection(interp, tkwin, selection, target, proc, clientData)
 
     if (dispPtr->multipleAtom == None) {
 	TkSelInit(tkwin);
-    }
+    }               
 
     /*
      * If the selection is owned by a window managed by this
@@ -804,7 +804,6 @@ Tk_SelectionCmd(clientData, interp, argc, argv)
 	    
 	Tk_ClearSelection(tkwin, selection);
 	return TCL_OK;
-#ifndef WIN32
     } else if ((c == 'e') && (strncmp(argv[1], "exists", length) == 0)) {
 	Window win = None;
 	for (count = argc-2, argp = argv+2; count > 0; count -= 2, argp += 2) {
@@ -859,7 +858,6 @@ Tk_SelectionCmd(clientData, interp, argc, argv)
 	    }
         }
 	return TCL_OK;
-#endif /* WIN32 */
     } else if ((c == 'g') && (strncmp(argv[1], "get", length) == 0)) {
 	Atom target;
 	char *targetName = NULL;
@@ -1467,7 +1465,12 @@ TkSelDefaultSelection(infoPtr, target, lbuffer, maxBytes, typePtr, formatPtr)
         *formatPtr = 8; 
 	return length;
     }
-
+        
+#if 0
+    LangDebug("Request %s type=%s\n",
+              Tk_GetAtomName((Tk_Window) winPtr, infoPtr->selection),
+              Tk_GetAtomName((Tk_Window) winPtr, target));
+#endif
     return -1;
 }
 
